==> prestashop_1.4.9.0.zip: prestashop/modules/merchantware/fr.php <==
<?php

global $_MODULE;
$_MODULE = array();
$_MODULE['<{merchantware}prestashop>merchantware_373956a1f29f19c8a4648482e0003721'] = 'MerchantWare';
$_MODULE['<{merchantware}prestashop>merchantware_d8ed6fc39d04722015bdc17aee4f99bc'] = 'Specialized in providing customized payment processing solutions for businesses nationwide.	';
$_MODULE['<{merchantware}prestashop>merchantware_69a1a3ad8dd5da6db3c4da838a0cf9c7'] = 'Are you sure you want to delete your details?	';
$_MODULE['<{merchantware}prestashop>merchantware_a04fc5e602d3f25b86936724236eba60'] = 'In order to use your module, please activate Soap	';
$_MODULE['<{merchantware}prestashop>merchantware_0f98b7f230f3c91292f0de4c99e263f2'] = 'Registration';
$_MODULE['<{merchantware}prestashop>merchantware_03bc142e6422dbb9b288ad2cabee08c7'] = 'Credential	';
$_MODULE['<{merchantware}prestashop>merchantware_ebd9bec4d70abc789d439c1f136b0538'] = 'Layout	';
$_MODULE['<{merchantware}prestashop>merchantware_c48fb18ab9d562b42911cddcdc0c855f'] = 'Authentification';
$_MODULE['<{merchantware}prestashop>merchantware_a3a79453fa83680e9ddd219c051ab213'] = 'In order to use the module, please fill out the form	';
$_MODULE['<{merchantware}prestashop>merchantware_9f5d4a26a690325988786ced21199e95'] = 'Merchant Name';
$_MODULE['<{merchantware}prestashop>merchantware_860d43ed270cd88ba701bd0acc3cadb6'] = 'The name of the business or organization owning the Merchantware account.	';
$_MODULE['<{merchantware}prestashop>merchantware_110c06456ebe280bce98dbb950a55931'] = 'Merchant Site ID	';
$_MODULE['<{merchantware}prestashop>merchantware_68e9703f103006df03a346609aa3a1b5'] = 'The site identifier of a location or storefront owned by the Merchantware account owner.	';
$_MODULE['<{merchantware}prestashop>merchantware_795acb9a0c89791314d3032fe65eeb92'] = 'Merchant Key	';
$_MODULE['<{merchantware}prestashop>merchantware_f6e39f0f5ec942723d6a474ec69df0cd'] = 'The software key or password for the site accessing a Merchantware account.	';
$_MODULE['<{merchantware}prestashop>merchantware_ccbe18d01c0fa2411b26223fe2ca803d'] = 'Keyed view and Swipe view	';
$_MODULE['<{merchantware}prestashop>merchantware_ec16a7e3c49cf747edcc92d2203d1f1f'] = 'The Display Colors structure provides customization of certain display elements on the Keyed view and Swipe view. All of the fields must be a valid hexadecimal HTML color code in RRGGBB format.	';
$_MODULE['<{merchantware}prestashop>merchantware_8c2857a9ad1d8f31659e35e904e20fa6'] = 'Logo';
$_MODULE['<{merchantware}prestashop>merchantware_e0cf387b1e97ef1b15e65e4807097aab'] = 'An SSL-secured URL pointing to an image file representing the shop\'s logo. The logo may be up to 430 pixels wide.	';
$_MODULE['<{merchantware}prestashop>merchantware_65b5ffe0bd2f2b717e7624fb66a0f630'] = 'Screen Background Color	';
$_MODULE['<{merchantware}prestashop>merchantware_08230e3c0b887f082dde23741d0fd13c'] = 'The background color of the screen.	';
$_MODULE['<{merchantware}prestashop>merchantware_2606bf2b8808d3f3010bbba40953c739'] = 'Container Background Color	';
$_MODULE['<{merchantware}prestashop>merchantware_e814760176099570d1bcc8312370d570'] = 'The background color of all standard display boxes.	';
$_MODULE['<{merchantware}prestashop>merchantware_3ab15b02b129a493357a68b7729505b9'] = 'Container Font Color	';
$_MODULE['<{merchantware}prestashop>merchantware_af3cc72035aba920731f271dcc5f8a00'] = 'The color of the text within all standard display boxes.	';
$_MODULE['<{merchantware}prestashop>merchantware_e6022eaa24b09085706485d7b112fa26'] = 'Container Help Font Color	';
$_MODULE['<{merchantware}prestashop>merchantware_c1a4051c27f2ff94e717ce12a53c111f'] = 'The color of help and tooltip text within all standard display boxes.	';
$_MODULE['<{merchantware}prestashop>merchantware_d727dc2af8301c7332398a012b3a7f10'] = 'Container Border Color	';
$_MODULE['<{merchantware}prestashop>merchantware_1479a67d4120fd8373d59bdbabd51b69'] = 'The border color for all standard display boxes.	';
$_MODULE['<{merchantware}prestashop>merchantware_f12f20fbae735b6f502f83a6759ba86c'] = 'Logo Background Color	';
$_MODULE['<{merchantware}prestashop>merchantware_6076ce1bb04bcf637080e76f6e4130b1'] = 'The background color for the box that contains a merchant supplied logo.	';
$_MODULE['<{merchantware}prestashop>merchantware_0bd11814aafbaf0800b9ba9423a36a5d'] = 'Logo Border Color	';
$_MODULE['<{merchantware}prestashop>merchantware_9a26957b595db6ab33c87bca468dd8b1'] = 'The border color for the box that contains a merchant supplied logo.	';
$_MODULE['<{merchantware}prestashop>merchantware_dd334cd81e863a02af4084c499901388'] = 'Tooltip Background Color	';
$_MODULE['<{merchantware}prestashop>merchantware_97801778061c03eb007adece4fcc545d'] = 'The background color for hovering tooltips.	';
$_MODULE['<{merchantware}prestashop>merchantware_48f041bffb4df901457ed79616e4c843'] = 'Tooltip Border Color	';
$_MODULE['<{merchantware}prestashop>merchantware_820b66e4fa9302a42cd2da902be80f6a'] = 'The border color for hovering tooltips.	';
$_MODULE['<{merchantware}prestashop>merchantware_57c67808fcb9229b788f63c1eb0f1449'] = 'Tooltip Font Color	';
$_MODULE['<{merchantware}prestashop>merchantware_87402974a74c013128cb4d54d1a18bf8'] = 'The font color for hovering tooltips.	';
$_MODULE['<{merchantware}prestashop>merchantware_5ff6518873122952539654b070d028c7'] = 'Textbox Background Color	';
$_MODULE['<{merchantware}prestashop>merchantware_219527159da69f54a458952f1fc36b86'] = 'The background color for text boxes where users enter information that do not have focus.	';
$_MODULE['<{merchantware}prestashop>merchantware_d3a6989aed94ab6c853f84927aaf2767'] = 'Textbox Border Color	';
$_MODULE['<{merchantware}prestashop>merchantware_249950798e012f1d02626dccc29c3b25'] = 'The border color for text boxes where users enter information that do not have focus.	';
$_MODULE['<{merchantware}prestashop>merchantware_cd9761b6577bb6063a9290eb5d5dc5f8'] = 'Textbox Focus Background Color	';
$_MODULE['<{merchantware}prestashop>merchantware_4b07e47d11ff0dabeac39753d2d6ef2f'] = 'The background color for text boxes where users enter information that have focus.	';
$_MODULE['<{merchantware}prestashop>merchantware_7acc6c57a5f9e4bf7adc7b5f68b8f931'] = 'Textbox Focus Border Color	';
$_MODULE['<{merchantware}prestashop>merchantware_67189884dcece971cf7ed3bb87bc2b14'] = 'Textbox Font Color	';
$_MODULE['<{merchantware}prestashop>merchantware_07ab7f4c132d7fd572de38d76c828889'] = 'The color of the text within a textbox.	';
$_MODULE['<{merchantware}prestashop>merchantware_e5d5173caf8231705f1f96aadfc4a6ce'] = 'Please full fill the entire form.	';
$_MODULE['<{merchantware}prestashop>merchantware_3a2bf9e262bf6b6363c391e074acb296'] = 'Your Merchant Name has to be less than 160 caracters.	';
$_MODULE['<{merchantware}prestashop>merchantware_7e43b50e6a513c1057fb22eb615ae473'] = 'Your Merchant Site Id has to be less than 160 caracters and more than 8 caracters.	';
$_MODULE['<{merchantware}prestashop>merchantware_3fee6af6b92457392a61de2b60b5a884'] = 'Your Merchant Key has to be less than 160 caracters.	';
$_MODULE['<{merchantware}prestashop>merchantware_56ffe6f5a5936f80a7113e7e629087dd'] = 'must be a valid hexadecimal HTML color code in RRGGBB format.	';
$_MODULE['<{merchantware}prestashop>merchantware_bccbad3b176c1c8bb202eee11b9d4216'] = 'Updated succesfully	';
$_MODULE['<{merchantware}prestashop>merchantware_5ec18b6f1ae93384941810451ad81220'] = 'Please, activate Soap.	';
$_MODULE['<{merchantware}prestashop>merchantware_e86bb93d4be226e5e9ec5aac76598547'] = 'Action succeded.	';
$_MODULE['<{merchantware}prestashop>merchantware_5d75b7f7a50593fb3c21583b732fc113'] = 'ERROR, please contact MerchantWare for Support assistance.';
$_MODULE['<{merchantware}prestashop>adminorder_fb8a8ee93f02d617edf5bb7a77b08819'] = 'Options Merchant Ware';
$_MODULE['<{merchantware}prestashop>adminorder_cda025244aeb28e8578d4799c39225b9'] = 'Changez le statut à \'Annuler\' pour annuler le paiement\'';
$_MODULE['<{merchantware}prestashop>adminorder_aaf85218338922f524d3d7762d4da80c'] = 'Changez le statut à \'Remboursé\' pour rembourser la totalité de la commande';
$_MODULE['<{merchantware}prestashop>credential_c9cc8cce247e49bae79f15173ce97354'] = 'Enregistrer';
$_MODULE['<{merchantware}prestashop>intro_a96005bf7f6f4b6f39485a58ecf911dc'] = 'Formulaire d\'inscription';
$_MODULE['<{merchantware}prestashop>intro_1c76cbfe21c6f44c1d1e59d54f3e4420'] = 'Société';
$_MODULE['<{merchantware}prestashop>intro_04176f095283bc729f1e3926967e7034'] = 'Prénom';
$_MODULE['<{merchantware}prestashop>intro_dff4bf10409100d989495c6d5486035e'] = 'Nom';
$_MODULE['<{merchantware}prestashop>intro_ce8ae9da5b7cd6c3df2929543a9af92d'] = 'E-mail';
$_MODULE['<{merchantware}prestashop>intro_dd7bf230fde8d4836917806aff6a6b27'] = 'Adresse';
$_MODULE['<{merchantware}prestashop>intro_57d056ed0984166336b7879c2af3657f'] = 'Ville';
$_MODULE['<{merchantware}prestashop>intro_46a2a41cc6e552044816a2d04634545d'] = 'Etat';
$_MODULE['<{merchantware}prestashop>intro_5e178542b85fb18ca3c459e9a95f4f2e'] = 'Code postal';
$_MODULE['<{merchantware}prestashop>intro_1e4dbc7eaa78468a3bc1448a3d68d906'] = 'Numéro de téléphone';
$_MODULE['<{merchantware}prestashop>intro_d7aa7433c6172c100d9c2972281c27c1'] = 'Numéro de téléphone personnel';
$_MODULE['<{merchantware}prestashop>intro_063ed8244d31b0c23b35bab75446ed3c'] = 'Produits vendus / Services fournis';
$_MODULE['<{merchantware}prestashop>intro_0f98b7f230f3c91292f0de4c99e263f2'] = 'Inscription';
$_MODULE['<{merchantware}prestashop>layout_c9cc8cce247e49bae79f15173ce97354'] = 'Enregistrer';
$_MODULE['<{merchantware}prestashop>payment_86b50ffb7db0a9f94c3af71b86af39e8'] = 'Payé avec MerchantWare';
$_MODULE['<{merchantware}prestashop>redirect_eaac93347037935034bdcdbb21ebfd58'] = 'Une erreur est survenue, veuillez réessayer plus tard.';
$_MODULE['<{merchantware}prestashop>redirect_85d448332d10907ef8cfb43f6d755761'] = 'Vous allez etre redirigé, si vous ne l\'etes pas, veuillez cliquer';
$_MODULE['<{merchantware}prestashop>redirect_7e1321b3c8423b30c1cb077a2e3ac4f0'] = 'ici';

==> prestashop_1.4.10.0.zip: prestashop/modules/merchantware/fr.php <==
<?php

global $_MODULE;
$_MODULE = array();
$_MODULE['<{merchantware}prestashop>merchantware_f67029f0590c89949df7250b045c00ae'] = 'Merchant Warehouse';
$_MODULE['<{merchantware}prestashop>merchantware_a81fb35373cd29bfb453c3f3f2d2dc2f'] = 'Eliminate expensive and unnecessary gateway fees by partnering with Merchant Warehouse for your payment processing needs!';
$_MODULE['<{merchantware}prestashop>merchantware_69a1a3ad8dd5da6db3c4da838a0cf9c7'] = 'Are you sure you want to delete your details?	';
$_MODULE['<{merchantware}prestashop>merchantware_f672dd7283da9b1f0bc81f2311a4bd33'] = 'In order to use your module, please activate Soap (PHP extension)';
$_MODULE['<{merchantware}prestashop>merchantware_18913710d984670f5c445289bf50a6ba'] = 'In order to use your module, please activate OpenSsl (PHP extension)';
$_MODULE['<{merchantware}prestashop>merchantware_11582f323e3cac72252135e07b353c1c'] = 'In order to use your module, please activate cURL (PHP extension)';
$_MODULE['<{merchantware}prestashop>merchantware_0f98b7f230f3c91292f0de4c99e263f2'] = 'Registration';
$_MODULE['<{merchantware}prestashop>merchantware_2daf1cb573c2c61422faf64610cf9402'] = 'Credentials';
$_MODULE['<{merchantware}prestashop>merchantware_ebd9bec4d70abc789d439c1f136b0538'] = 'Layout';
$_MODULE['<{merchantware}prestashop>merchantware_bffe9a3c9a7e00ba00a11749e022d911'] = 'Log in';
$_MODULE['<{merchantware}prestashop>merchantware_b9990075a8978dccda5cd15ea758ba21'] = 'In order to use this module, please fill out the form with the logins provided to you by Merchant Warehouse.';
$_MODULE['<{merchantware}prestashop>merchantware_9f5d4a26a690325988786ced21199e95'] = 'Merchant Name';
$_MODULE['<{merchantware}prestashop>merchantware_860d43ed270cd88ba701bd0acc3cadb6'] = 'The name of the business or organization owning the Merchantware account.	';
$_MODULE['<{merchantware}prestashop>merchantware_110c06456ebe280bce98dbb950a55931'] = 'Merchant Site ID	';
$_MODULE['<{merchantware}prestashop>merchantware_68e9703f103006df03a346609aa3a1b5'] = 'The site identifier of a location or storefront owned by the Merchantware account owner.	';
$_MODULE['<{merchantware}prestashop>merchantware_795acb9a0c89791314d3032fe65eeb92'] = 'Merchant Key	';
$_MODULE['<{merchantware}prestashop>merchantware_f6e39f0f5ec942723d6a474ec69df0cd'] = 'The software key or password for the site accessing a Merchantware account.	';
$_MODULE['<{merchantware}prestashop>merchantware_ccbe18d01c0fa2411b26223fe2ca803d'] = 'Keyed view and Swipe view	';
$_MODULE['<{merchantware}prestashop>merchantware_ec16a7e3c49cf747edcc92d2203d1f1f'] = 'The Display Colors structure provides customization of certain display elements on the Keyed view and Swipe view. All of the fields must be a valid hexadecimal HTML color code in RRGGBB format.	';
$_MODULE['<{merchantware}prestashop>merchantware_8c2857a9ad1d8f31659e35e904e20fa6'] = 'Logo';
$_MODULE['<{merchantware}prestashop>merchantware_e0cf387b1e97ef1b15e65e4807097aab'] = 'An SSL-secured URL pointing to an image file representing the shop\'s logo. The logo may be up to 430 pixels wide.	';
$_MODULE['<{merchantware}prestashop>merchantware_65b5ffe0bd2f2b717e7624fb66a0f630'] = 'Screen Background Color	';
$_MODULE['<{merchantware}prestashop>merchantware_08230e3c0b887f082dde23741d0fd13c'] = 'The background color of the screen.	';
$_MODULE['<{merchantware}prestashop>merchantware_2606bf2b8808d3f3010bbba40953c739'] = 'Container Background Color	';
$_MODULE['<{merchantware}prestashop>merchantware_e814760176099570d1bcc8312370d570'] = 'The background color of all standard display boxes.	';
$_MODULE['<{merchantware}prestashop>merchantware_3ab15b02b129a493357a68b7729505b9'] = 'Container Font Color	';
$_MODULE['<{merchantware}prestashop>merchantware_af3cc72035aba920731f271dcc5f8a00'] = 'The color of the text within all standard display boxes.	';
$_MODULE['<{merchantware}prestashop>merchantware_e6022eaa24b09085706485d7b112fa26'] = 'Container Help Font Color	';
$_MODULE['<{merchantware}prestashop>merchantware_c1a4051c27f2ff94e717ce12a53c111f'] = 'The color of help and tooltip text within all standard display boxes.	';
$_MODULE['<{merchantware}prestashop>merchantware_d727dc2af8301c7332398a012b3a7f10'] = 'Container Border Color	';
$_MODULE['<{merchantware}prestashop>merchantware_1479a67d4120fd8373d59bdbabd51b69'] = 'The border color for all standard display boxes.	';
$_MODULE['<{merchantware}prestashop>merchantware_f12f20fbae735b6f502f83a6759ba86c'] = 'Logo Background Color	';
$_MODULE['<{merchantware}prestashop>merchantware_6076ce1bb04bcf637080e76f6e4130b1'] = 'The background color for the box that contains a merchant supplied logo.	';
$_MODULE['<{merchantware}prestashop>merchantware_0bd11814aafbaf0800b9ba9423a36a5d'] = 'Logo Border Color	';
$_MODULE['<{merchantware}prestashop>merchantware_9a26957b595db6ab33c87bca468dd8b1'] = 'The border color for the box that contains a merchant supplied logo.	';
$_MODULE['<{merchantware}prestashop>merchantware_dd334cd81e863a02af4084c499901388'] = 'Tooltip Background Color	';
$_MODULE['<{merchantware}prestashop>merchantware_97801778061c03eb007adece4fcc545d'] = 'The background color for hovering tooltips.	';
$_MODULE['<{merchantware}prestashop>merchantware_48f041bffb4df901457ed79616e4c843'] = 'Tooltip Border Color	';
$_MODULE['<{merchantware}prestashop>merchantware_820b66e4fa9302a42cd2da902be80f6a'] = 'The border color for hovering tooltips.	';
$_MODULE['<{merchantware}prestashop>merchantware_57c67808fcb9229b788f63c1eb0f1449'] = 'Tooltip Font Color	';
$_MODULE['<{merchantware}prestashop>merchantware_87402974a74c013128cb4d54d1a18bf8'] = 'The font color for hovering tooltips.	';
$_MODULE['<{merchantware}prestashop>merchantware_5ff6518873122952539654b070d028c7'] = 'Textbox Background Color	';
$_MODULE['<{merchantware}prestashop>merchantware_219527159da69f54a458952f1fc36b86'] = 'The background color for text boxes where users enter information that do not have focus.	';
$_MODULE['<{merchantware}prestashop>merchantware_d3a6989aed94ab6c853f84927aaf2767'] = 'Textbox Border Color	';
$_MODULE['<{merchantware}prestashop>merchantware_249950798e012f1d02626dccc29c3b25'] = 'The border color for text boxes where users enter information that do not have focus.	';
$_MODULE['<{merchantware}prestashop>merchantware_cd9761b6577bb6063a9290eb5d5dc5f8'] = 'Textbox Focus Background Color	';
$_MODULE['<{merchantware}prestashop>merchantware_4b07e47d11ff0dabeac39753d2d6ef2f'] = 'The background color for text boxes where users enter information that have focus.	';
$_MODULE['<{merchantware}prestashop>merchantware_7acc6c57a5f9e4bf7adc7b5f68b8f931'] = 'Textbox Focus Border Color	';
$_MODULE['<{merchantware}prestashop>merchantware_67189884dcece971cf7ed3bb87bc2b14'] = 'Textbox Font Color	';
$_MODULE['<{merchantware}prestashop>merchantware_07ab7f4c132d7fd572de38d76c828889'] = 'The color of the text within a textbox.	';
$_MODULE['<{merchantware}prestashop>merchantware_685714a6c404dafacb93d5690edfb2a9'] = 'Please fill out the entire form.';
$_MODULE['<{merchantware}prestashop>merchantware_2d984cbc96ea757e26c5112246213b70'] = 'Your Merchant Name has to be less than 160 characters.';
$_MODULE['<{merchantware}prestashop>merchantware_84461bd1dc79e895f4ca0ea19fc00ed9'] = 'Your Merchant Site ID has to be less than 160 characters and more than 8 characters.';
$_MODULE['<{merchantware}prestashop>merchantware_f36e80206b529c0346a9217a27dfabd5'] = 'Your Merchant Key has to be less than 160 characters.';
$_MODULE['<{merchantware}prestashop>merchantware_56ffe6f5a5936f80a7113e7e629087dd'] = 'must be a valid hexadecimal HTML color code in RRGGBB format.	';
$_MODULE['<{merchantware}prestashop>merchantware_bccbad3b176c1c8bb202eee11b9d4216'] = 'Updated succesfully	';
$_MODULE['<{merchantware}prestashop>merchantware_e86bb93d4be226e5e9ec5aac76598547'] = 'Action succeded.	';
$_MODULE['<{merchantware}prestashop>merchantware_5d75b7f7a50593fb3c21583b732fc113'] = 'ERROR, please contact MerchantWare for Support assistance.';
$_MODULE['<{merchantware}prestashop>merchantware_4d4d94ae940767c7a70bb08ad75bef31'] = 'ERROR, please contact Merchant Warehouse for Support assistance.';
$_MODULE['<{merchantware}prestashop>admin_4c8778f06ee3574ad7a24fe09a64e4ee'] = 'Merchant Warehouse vous permet d\'accepter immédiatement des paiements sécurisés de la part de clients tout autour du monde.';
$_MODULE['<{merchantware}prestashop>admin_8ea211024d4a6ad6119a33549dae10d6'] = 'Créer un compte gratuit';
$_MODULE['<{merchantware}prestashop>admin_dcfb528fa42ffbefc5ec2161e138ed25'] = 'Pourquoi vous allez aimer Merchant Warehouse :';
$_MODULE['<{merchantware}prestashop>admin_133fbd51c86b33886cada89b5eda12bc'] = 'Plate-forme de paiements gratuite';
$_MODULE['<{merchantware}prestashop>admin_da1536a214a4eb0e3a545a3ac1b003ee'] = 'Aucun coût de transaction supplémentaire';
$_MODULE['<{merchantware}prestashop>admin_e6737b4a34e4f63b5254fff46e1cc554'] = 'Le service support, disponible gratuitement et 24h/24, est fourni par notre équipe interne primée pour son travail.';
$_MODULE['<{merchantware}prestashop>admin_d96a58931f5602c7a4a1182a3f617e32'] = 'Configuration du compte rapide et simple';
$_MODULE['<{merchantware}prestashop>admin_88181816380826279fd428b68532ce15'] = 'Certifié PDI-DSS';
$_MODULE['<{merchantware}prestashop>admin_5580c75410be538150f86efcef4495e5'] = 'Intégration transparente avec PrestaShop';
$_MODULE['<{merchantware}prestashop>admin_ff7945d13e68322cf1633d2604842c12'] = 'Outil de rapport des transactions';
$_MODULE['<{merchantware}prestashop>admin_fdb7fc6323155df72c6bec5edc3a99cd'] = 'Aucun contrat ni frais cachés';
$_MODULE['<{merchantware}prestashop>admin_2fdfd506efea08144c0794c32ca8250a'] = 'Créer un compte';
$_MODULE['<{merchantware}prestashop>admin_2f54da55d9465878e30b3d427da058ad'] = 'Acceptez les paiements à l\'échelle mondiale grâce à la plupart des cartes de crédit !';
$_MODULE['<{merchantware}prestashop>admin_65a326a79b9521b1215a1c110d463dcd'] = 'Plusieurs centaines de milliers d\'entreprises font déjà confiance a Merchant Warehouse grâce à sa rigueur. Une solution de paiement innovantes et accessible par tous.';
$_MODULE['<{merchantware}prestashop>adminorder_fb8a8ee93f02d617edf5bb7a77b08819'] = 'Options Merchant Ware';
$_MODULE['<{merchantware}prestashop>adminorder_cda025244aeb28e8578d4799c39225b9'] = 'Changez le statut à \'Annuler\' pour annuler le paiement\'';
$_MODULE['<{merchantware}prestashop>adminorder_aaf85218338922f524d3d7762d4da80c'] = 'Changez le statut à \'Remboursé\' pour rembourser la totalité de la commande';
$_MODULE['<{merchantware}prestashop>credential_c9cc8cce247e49bae79f15173ce97354'] = 'Enregistrer';
$_MODULE['<{merchantware}prestashop>intro_8b03c1150b1b2b2c606138c6e3b3abcd'] = 'Create your account TODAY by filling out the form below!';
$_MODULE['<{merchantware}prestashop>intro_1c76cbfe21c6f44c1d1e59d54f3e4420'] = 'Société';
$_MODULE['<{merchantware}prestashop>intro_bc910f8bdf70f29374f496f05be0330c'] = 'Prénom';
$_MODULE['<{merchantware}prestashop>intro_77587239bf4c54ea493c7033e1dbf636'] = 'Nom';
$_MODULE['<{merchantware}prestashop>intro_ce8ae9da5b7cd6c3df2929543a9af92d'] = 'E-mail';
$_MODULE['<{merchantware}prestashop>intro_dd7bf230fde8d4836917806aff6a6b27'] = 'Adresse';
$_MODULE['<{merchantware}prestashop>intro_57d056ed0984166336b7879c2af3657f'] = 'Ville';
$_MODULE['<{merchantware}prestashop>intro_46a2a41cc6e552044816a2d04634545d'] = 'Etat';
$_MODULE['<{merchantware}prestashop>intro_5e178542b85fb18ca3c459e9a95f4f2e'] = 'Code postal';
$_MODULE['<{merchantware}prestashop>intro_1e4dbc7eaa78468a3bc1448a3d68d906'] = 'Numéro de téléphone';
$_MODULE['<{merchantware}prestashop>intro_d7aa7433c6172c100d9c2972281c27c1'] = 'Numéro de téléphone personnel';
$_MODULE['<{merchantware}prestashop>intro_d1873a71f318c4e4733240f0b5911af3'] = 'Products sold';
$_MODULE['<{merchantware}prestashop>intro_1518d8929229dbcca4d7c6f3f763311a'] = 'or Services provided';
$_MODULE['<{merchantware}prestashop>intro_0ba7583639a274c434bbe6ef797115a4'] = 'Register';
$_MODULE['<{merchantware}prestashop>layout_c9cc8cce247e49bae79f15173ce97354'] = 'Enregistrer';
$_MODULE['<{merchantware}prestashop>payment_86b50ffb7db0a9f94c3af71b86af39e8'] = 'Payé avec MerchantWare';
$_MODULE['<{merchantware}prestashop>redirect_eaac93347037935034bdcdbb21ebfd58'] = 'Une erreur est survenue, veuillez réessayer plus tard.';
$_MODULE['<{merchantware}prestashop>redirect_85d448332d10907ef8cfb43f6d755761'] = 'Vous allez etre redirigé, si vous ne l\'etes pas, veuillez cliquer';
$_MODULE['<{merchantware}prestashop>redirect_7e1321b3c8423b30c1cb077a2e3ac4f0'] = 'ici';
